part of 'auth_bloc.dart';

abstract class AuthState {}

class AuthInitial extends AuthState {}

class AuthLoading extends AuthState {}

// ADDED: State to indicate the result of the token check
class AuthChecked extends AuthState {
  final bool hasToken;
  AuthChecked(this.hasToken);
}

// ADDED: State for when the user has a shop
class ShopExists extends AuthState {}

// ADDED: State for when the user is logged in but has no shop
class NoShop extends AuthState {}

class AuthCodeSentSuccess extends AuthState {}

class AuthVerified extends AuthState {}

class UserInfoSaved extends AuthState {}

class AuthFailure extends AuthState {
  final String message;

  AuthFailure(this.message);
}